@@ -41,10 +41,54 @@ LearnerRegr = R6Class("LearnerRegr", inherit = Learner,
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, param_set = ps(), predict_types = "response", feature_types = character(), properties = character(), data_formats = "data.table", packages = character(), label = NA_character_, man = NA_character_) {
+    initialize = function(id, param_set = ps(), predict_types = "response", feature_types = character(), properties = character(), data_formats, packages = character(), label = NA_character_, man = NA_character_) {
       super$initialize(id = id, task_type = "regr", param_set = param_set, feature_types = feature_types,
-        predict_types = predict_types, properties = properties, data_formats = data_formats, packages = packages,
+        predict_types = predict_types, properties = properties, data_formats, packages = packages,
         label = label, man = man)
     }
+  ),
+
+  active = list(
+
+    #' @field quantiles (`numeric()`)\cr
+    #' Numeric vector of probabilities to be used while predicting quantiles.
+    #' Elements must be between 0 and 1, not missing and provided in ascending order.
+    #' If only one quantile is provided, it is used as response.
+    #' Otherwise, set `$quantile_response` to specify the response quantile.
+    quantiles = function(rhs) {
+      if (missing(rhs)) {
+        return(private$.quantiles)
+      }
+
+      if ("quantiles" %nin% self$predict_types) {
+        stopf("Learner does not support predicting quantiles")
+      }
+      private$.quantiles = assert_numeric(rhs, lower = 0, upper = 1, any.missing = FALSE, min.len = 1L, sorted = TRUE, .var.name = "quantiles")
+
+      if (length(private$.quantiles) == 1) {
+        private$.quantile_response = private$.quantiles
+      }
+    },
+
+    #' @field quantile_response (`numeric(1)`)\cr
+    #' The quantile to be used as response.
+    quantile_response = function(rhs) {
+      if (missing(rhs)) {
+        return(private$.quantile_response)
+      }
+
+      if ("quantiles" %nin% self$predict_types) {
+        stopf("Learner does not support predicting quantiles")
+      }
+
+      private$.quantile_response = assert_number(rhs, lower = 0, upper = 1, .var.name = "response")
+      private$.quantiles = sort(union(private$.quantiles, private$.quantile_response))
+    }
+  ),
+
+
+  private = list(
+    .quantiles = NULL,
+    .quantile_response = NULL
   )
 )
