@@ -28,7 +28,7 @@ LearnerRegrFeatureless = R6Class("LearnerRegrFeatureless", inherit = LearnerRegr
       super$initialize(
         id = "regr.featureless",
         feature_types = unname(mlr_reflections$task_feature_types),
-        predict_types = c("response", "se"),
+        predict_types = c("response", "se", "quantiles"),
         param_set = ps,
         properties = c("featureless", "missings", "importance", "selected_features"),
         packages = "stats",
@@ -61,6 +61,14 @@ LearnerRegrFeatureless = R6Class("LearnerRegrFeatureless", inherit = LearnerRegr
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
       x = task$data(cols = task$target_names)[[1L]]
+
+      quantiles = if (self$predict_type == "quantiles") {
+        if (is.null(private$.quantiles) || is.null(private$.quantile_response)) {
+          stop("Quantiles '$quantiles' and response quantile '$quantile_response' must be set")
+        }
+        quantile(x, probs = private$.quantiles)
+      }
+
       if (isFALSE(pv$robust)) {
         location = mean(x)
         dispersion = sd(x)
@@ -68,11 +76,24 @@ LearnerRegrFeatureless = R6Class("LearnerRegrFeatureless", inherit = LearnerRegr
         location = stats::median(x)
         dispersion = stats::mad(x, center = location)
       }
-      set_class(list(location = location, dispersion = dispersion, features = task$feature_names), "regr.featureless_model")
+
+      set_class(list(
+        location = location,
+        dispersion = dispersion,
+        quantiles = quantiles,
+        features = task$feature_names), "regr.featureless_model")
     },
 
     .predict = function(task) {
       n = task$nrow
+
+      if (self$predict_type == "quantiles") {
+        quantiles = matrix(rep(self$model$quantiles, n), nrow = n, byrow = TRUE)
+        attr(quantiles, "probs") = private$.quantiles
+        attr(quantiles, "response") = private$.quantile_response
+        return(list(quantiles = quantiles))
+      }
+
       response = rep(self$model$location, n)
       se = if (self$predict_type == "se") rep(self$model$dispersion, n) else NULL
       list(response = response, se = se)
