@@ -37,7 +37,8 @@ MeasureSelectedFeatures = R6Class("MeasureSelectedFeatures",
         id = "selected_features",
         param_set = param_set,
         task_type = NA_character_,
-        properties = c("requires_task", "requires_learner", "requires_model"),
+        properties = c("requires_task", "requires_learner", "requires_model", "requires_no_prediction"),
+        predict_sets = NULL,
         predict_type = NA_character_,
         range = c(0, Inf),
         minimize = TRUE,
