@@ -16,7 +16,8 @@ NULL
 
 load_task_pima = function(id = "pima") {
   b = as_data_backend(load_dataset("PimaIndiansDiabetes2", "mlbench"))
-  task = TaskClassif$new(id, b, target = "diabetes", positive = "pos")
+  task = TaskClassif$new(id, b, target = "diabetes", positive = "pos",
+    label = "Pima Indian Diabetes")
   b$hash = task$man = "mlr3::mlr_tasks_pima"
   task
 }
