@@ -241,7 +241,7 @@ test_that("empty predict set (#421)", {
 
 test_that("fallback learner is deep cloned (#511)", {
   l = lrn("classif.rpart")
-  l$fallback = lrn("classif.featureless")
+  l$encapsulate("evaluate",lrn("classif.featureless"))
   expect_different_address(l$fallback, l$clone(deep = TRUE)$fallback)
 })
 
@@ -327,7 +327,8 @@ test_that("Models can be replaced", {
 
 test_that("validation task's backend is removed", {
   learner = lrn("regr.rpart")
-  task = tsk("mtcars")$divide(ids = 1:10)
+  task = tsk("mtcars")
+  task$internal_valid_task = 1:10
   learner$train(task)
   expect_true(is.null(learner$state$train_task$internal_valid_task$backend))
 })
@@ -340,7 +341,7 @@ test_that("manual $train() stores validation hash and validation ids", {
 
   l = lrn("classif.debug", validate = "predefined")
   task = tsk("iris")
-  task$divide(ids = 1:10)
+  task$internal_valid_task = 1:10
   l$train(task)
   expect_equal(l$state$internal_valid_task_hash, task$internal_valid_task$hash)
 
@@ -354,7 +355,7 @@ test_that("error when training a learner that sets valiadte to 'predefined' on a
   task = tsk("iris")
   learner = lrn("classif.debug", validate = "predefined")
   expect_error(learner$train(task), "is set to 'predefined'")
-  task$divide(ids = 1:10)
+  task$internal_valid_task = 1:10
   expect_class(learner, "Learner")
 })
 
@@ -364,7 +365,7 @@ test_that("properties are also checked on validation task", {
   row[[1]][1] = NA
   row$..row_id = 151
   task$rbind(row)
-  task$divide(ids = 151)
+  task$internal_valid_task = 151
   learner = lrn("classif.debug", validate = "predefined")
   learner$properties = setdiff(learner$properties, "missings")
   expect_error(learner$train(task), "missing values")
@@ -382,14 +383,14 @@ test_that("marshaling and encapsulation", {
   learner = lrn("classif.debug", count_marshaling = TRUE)
 
   # callr encapsulation causes marshaling
-  learner$encapsulate = c(train = "callr")
+  learner$encapsulate("callr", lrn("classif.featureless"))
   learner$train(task)
   expect_equal(learner$model$marshal_count, 1)
   expect_false(learner$marshaled)
   expect_prediction(learner$predict(task))
 
   # no marshaling with no other encapsulation
-  learner$encapsulate = c(train = "none")
+  learner$encapsulate("none")
   learner$train(task)
   expect_equal(learner$model$marshal_count, 0)
 })
@@ -416,7 +417,8 @@ test_that("internal_valid_task is created correctly", {
   )
   # validate = NULL (but task has one)
   learner = LearnerClassifTest$new()
-  task = tsk("iris")$divide(0.3)
+  task = tsk("iris")
+  task$internal_valid_task = partition(task)$test
   learner$train(task)
   learner$validate = NULL
   expect_true(is.null(learner$internal_valid_scores))
@@ -480,14 +482,15 @@ test_that("internal_valid_task is created correctly", {
 
 test_that("compatability check on validation task", {
   learner = lrn("classif.debug", validate = "predefined")
-  task = tsk("german_credit")$divide(ids = 1:10)
+  task = tsk("german_credit")
+  task$internal_valid_task = 1:10
   task$col_roles$feature = "age"
   expect_error(learner$train(task), "has different features")
   task$internal_valid_task$col_roles$feature = "age"
   task$internal_valid_task$col_roles$target = "credit_history"
   expect_error(learner$train(task), "has different target")
 })
-  
+
 test_that("model is marshaled during parallel predict", {
   # by setting check_pid = TRUE, we ensure that unmarshal_model() sets the process id to the current
   # id. LearnerClassifDebug then checks during `.predict()`, whether the marshal_id of the model is equal to the current process id and errs if this is not the case.
@@ -505,7 +508,8 @@ test_that("model is marshaled during callr prediction", {
   # by setting check_pid = TRUE, we ensure that unmarshal_model() sets the process id to the current
   # id. LearnerClassifDebug then checks during `.predict()`, whether the marshal_id of the model is equal to the current process id and errs if this is not the case.
   task = tsk("iris")
-  learner = lrn("classif.debug", check_pid = TRUE, encapsulate = c(predict = "callr"))
+  learner = lrn("classif.debug", check_pid = TRUE)
+  learner$encapsulate("callr", lrn("classif.featureless"))
   learner$train(task)
   pred = learner$predict(task)
   expect_class(pred, "Prediction")
@@ -513,7 +517,8 @@ test_that("model is marshaled during callr prediction", {
 
 test_that("predict leaves marshaling status as-is", {
   task = tsk("iris")
-  learner = lrn("classif.debug", check_pid = TRUE, encapsulate = c(predict = "callr"))
+  learner = lrn("classif.debug", check_pid = TRUE)
+  learner$encapsulate("callr", lrn("classif.featureless"))
   learner$train(task)
   learner$marshal()
   expect_class(learner$predict(task), "Prediction")
@@ -537,13 +542,90 @@ test_that("learner state contains internal valid task information", {
   expect_string(rr$learners[[1L]]$state$internal_valid_task_hash)
 
   # 1. manual
-  learner$train(task) 
+  learner$train(task)
   expect_string(learner$state$internal_valid_task_hash)
 })
 
 test_that("validation task with 0 observations", {
   learner = lrn("classif.debug", validate = "predefined")
   task = tsk("iris")
-  task$divide(ids = integer(0))
+  task$internal_valid_task = integer(0)
   expect_error({learner$train(task)}, "has 0 observations")
 })
+
+test_that("column info is compared during predict", {
+  x = c("a", "b")
+  d = data.table(
+    x = factor(x, levels = c("a", "b")),
+    y = 1:2
+  )
+
+  dflip = data.table(
+    x = factor(x, labels = c("b", "a"), levels = c("b", "a")),
+    y = 1:2
+  )
+
+  dother = data.table(
+    x1 = factor(c("a", "b")),
+    y = 1:2
+  )
+
+  task = as_task_classif(d, target = "y")
+  task_flip = as_task_classif(dflip, target = "y")
+  task_other = as_task_classif(dother, target = "y")
+  l = lrn("classif.rpart")
+  l$train(task)
+  old_threshold = lg$threshold
+  lg$set_threshold("warn")
+  expect_output(l$predict(task_flip), "task with different column info")
+  lg$set_threshold(old_threshold)
+  expect_error(l$predict(task_other), "with different columns")
+})
+
+test_that("quantiles in LearnerRegr", {
+  task = tsk("mtcars")
+  learner = lrn("regr.debug", predict_type = "quantiles")
+  expect_learner(learner)
+  quantiles = c(0.05, 0.5, 0.95)
+  learner$quantiles = quantiles
+
+  expect_numeric(learner$quantiles, any.missing = FALSE, len = 3)
+
+  learner$quantile_response = 0.6
+  expect_equal(learner$quantile_response, 0.6)
+  expect_equal(learner$quantiles, c(0.05, 0.5, 0.6, 0.95))
+
+  expect_error({
+    learner$quantiles = c(0.5, 0.1)
+  }, "sorted")
+
+  expect_error({
+    learner$quantiles = integer()
+  }, "length")
+
+  learner$train(task)
+
+  expect_numeric(learner$model$quantiles, len = 4L)
+
+  pred = learner$predict(task)
+  expect_prediction(pred)
+  expect_subset("quantiles", pred$predict_types)
+  expect_matrix(pred$quantiles, ncols = 4L, nrows = task$nrow, any.missing = FALSE)
+  expect_true(!any(apply(pred$quantiles, 1L, is.unsorted)))
+  expect_equal(pred$response, pred$quantiles[, 3L])
+
+  tab = as.data.table(pred)
+  expect_data_table(tab, nrows = task$nrow)
+  expect_subset("q0.5", names(tab))
+})
+
+test_that("predict time is cumulative", {
+  learner = lrn("classif.debug", sleep_predict = function() 0.05)
+  task = tsk("iris")
+  learner$train(task)$predict(task)
+  t1 = learner$timings["predict"]
+  learner$param_set$values$sleep_predict = function() 0.01
+  learner$predict(task)
+  t2 = learner$timings["predict"]
+  expect_true(t1 > t2)
+})
