@@ -7,17 +7,17 @@ bmr = benchmark(design)
 
 test_that("Basic benchmarking", {
   expect_benchmark_result(bmr)
-  expect_names(names(as.data.table(bmr)), permutation.of = c(mlr_reflections$rr_names, "uhash"))
+  expect_names(names(as.data.table(bmr)), permutation.of = c(mlr_reflections$rr_names, "uhash", "prediction"))
 
   tab = as.data.table(bmr)
   expect_data_table(tab, nrows = 18L, ncols = 6L)
-  expect_names(names(tab), permutation.of = c("uhash", mlr_reflections$rr_names))
+  expect_names(names(tab), permutation.of = c("uhash", "prediction", mlr_reflections$rr_names))
   measures = list(msr("classif.acc"))
 
-  tab = bmr$score(measures, ids = FALSE)
+  tab = bmr$score(measures, ids = FALSE, predictions = TRUE)
   expect_data_table(tab, nrows = 18L, ncols = 7L + length(measures))
-  expect_names(names(tab), must.include = c("nr", "uhash", mlr_reflections$rr_names, ids(measures)))
-  expect_list(tab$prediction, "Prediction")
+  expect_names(names(tab), must.include = c("nr", "uhash", "prediction_test", mlr_reflections$rr_names, ids(measures)))
+  expect_list(tab$prediction_test, "Prediction")
 
   tab = bmr$tasks
   expect_data_table(tab, nrows = 3L, any.missing = FALSE)
@@ -301,8 +301,8 @@ test_that("encapsulatiion", {
 
   for (learner in bmr$learners$learner) {
     expect_class(learner$fallback, "LearnerClassifFeatureless")
-    expect_equal(learner$encapsulate[["train"]], "evaluate")
-    expect_equal(learner$encapsulate[["predict"]], "evaluate")
+    expect_equal(learner$encapsulation[["train"]], "evaluate")
+    expect_equal(learner$encapsulation[["predict"]], "evaluate")
   }
 })
 
@@ -421,7 +421,7 @@ test_that("param_values in benchmark", {
   expect_benchmark_result(bmr)
   expect_equal(bmr$n_resample_results, 1)
   expect_equal(nrow(as.data.table(bmr)), 3)
-  learner = bmr$learners$learner[[1]]
+  learner = bmr$resample_result(1)$learner
   expect_equal(learner$param_set$values$x, 1)
   expect_equal(nrow(as.data.table(bmr)), 3)
 
@@ -431,9 +431,9 @@ test_that("param_values in benchmark", {
   expect_benchmark_result(bmr)
   expect_equal(bmr$n_resample_results, 2)
   expect_equal(nrow(as.data.table(bmr)), 6)
-  learner = bmr$learners$learner[[1]]
+  learner = bmr$resample_result(1)$learner
   expect_equal(learner$param_set$values$x, 1)
-  learner = bmr$learners$learner[[2]]
+  learner = bmr$resample_result(2)$learner
   expect_equal(learner$param_set$values$x, 0.5)
 
   # benchmark grid does not attach param_values if empty
@@ -486,3 +486,98 @@ test_that("param_values in benchmark", {
   expect_equal(sortnames(bmr$learners$learner[-ii][[1]]$param_set$values), list(minbucket = 2, minsplit = 12, xval = 0))
   expect_equal(sortnames(bmr$learners$learner[[ii]]$param_set$values), list(cp = 0.1, minsplit = 12, xval = 0))
 })
+
+
+test_that("learner's validate cannot be 'test' if internal_valid_set is present", {
+  # otherwise, predict_set = "internal_valid" would be ambiguous
+  learner = lrn("classif.debug", validate = "test", predict_sets = c("train", "internal_valid"))
+  task = tsk("iris")
+  task$internal_valid_task = 1
+  expect_error(benchmark(benchmark_grid(task, learner, rsmp("holdout"))), "cannot be set to ")
+})
+
+test_that("learner's validate cannot be a ratio if internal_valid_set is present", {
+  # otherwise, predict_set = "internal_valid" would be ambiguous
+  learner = lrn("classif.debug", validate = 0.5, predict_sets = c("train", "internal_valid"))
+  task = tsk("iris")
+  task$internal_valid_task = 1
+  expect_error(benchmark(benchmark_grid(task, learner, rsmp("holdout"))), "cannot be set to ")
+})
+
+test_that("properties are also checked on validation task", {
+  task = tsk("iris")
+  row = task$data(1)
+  row[[1]][1] = NA
+  row$..row_id = 151
+  task$rbind(row)
+  task$internal_valid_task = 151
+  learner = lrn("classif.debug", validate = "predefined")
+  learner$properties = setdiff(learner$properties, "missings")
+
+  expect_error(benchmark(benchmark_grid(task, learner, rsmp("holdout"))), "missing values")
+})
+
+test_that("unmarshal parameter is respected", {
+  learner = lrn("classif.debug", count_marshaling = TRUE)
+  learner$encapsulate("callr", lrn("classif.featureless"))
+  task = tsk("iris")
+  resampling = rsmp("holdout")
+  design = benchmark_grid(task, learner, resampling)
+  bmr = with_future(future::multisession, {
+    list(
+      marshaled = benchmark(design, store_models = TRUE, unmarshal = FALSE),
+      unmarshaled = benchmark(design, store_models = TRUE, unmarshal = TRUE)
+    )
+  })
+  expect_false(bmr$unmarshaled$resample_result(1)$learners[[1]]$marshaled)
+  expect_true(bmr$marshaled$resample_result(1)$learners[[1]]$marshaled)
+})
+
+test_that("BenchmarkResult can be (un)marshaled", {
+  bmr = benchmark(benchmark_grid(tsk("iris"), lrn("classif.debug"), rsmp("holdout")), store_models = TRUE)
+  expect_false(bmr$resample_result(1)$learners[[1]]$marshaled)
+  bmr$marshal()
+  expect_true(bmr$resample_result(1)$learners[[1]]$marshaled)
+  bmr$unmarshal()
+  expect_false(bmr$resample_result(1)$learners[[1]]$marshaled)
+
+  # also works with non-marshalable learner
+  bmr1 = benchmark(benchmark_grid(tsk("iris"), lrn("classif.featureless"), rsmp("holdout")), store_models = TRUE)
+  model = bmr1$resample_result(1)$learners[[1]]$model
+  bmr1$unmarshal()
+  expect_equal(bmr1$resample_result(1)$learners[[1]]$model, model)
+})
+
+test_that("obs_loss", {
+  bmr = benchmark(benchmark_grid(
+    tsk("iris"),
+    lrn("classif.rpart"),
+    rsmp("holdout")
+  ))
+  tbl = bmr$obs_loss(msrs(c("classif.acc", "classif.auc")))
+  expect_true(all(is.na(tbl$classif.auc)))
+  expect_integer(tbl$classif.acc)
+})
+
+test_that("predictions retrieved with as.data.table and predictions method are equal", {
+  tab = as.data.table(bmr)
+  predictions = unlist(map(bmr$resample_results$resample_result, function(rr) rr$predictions()), recursive = FALSE)
+  expect_equal(tab$prediction, predictions)
+
+  tab = as.data.table(bmr, predict_sets = "train")
+  predictions = unlist(map(bmr$resample_results$resample_result, function(rr) rr$predictions(predict_sets = "train")), recursive = FALSE)
+  expect_equal(tab$prediction, predictions)
+})
+
+test_that("score works with predictions and empty predictions", {
+  learner_1 = lrn("classif.rpart", predict_sets = "train", id = "learner_1")
+  learner_2 = lrn("classif.rpart", predict_sets = "test", id = "learner_2")
+  task = tsk("pima")
+
+  design = benchmark_grid(task, list(learner_1, learner_2), rsmp("holdout"))
+
+  bmr = benchmark(design)
+
+  expect_warning({tab = bmr$score(msr("classif.ce", predict_sets = "test"))}, "Measure")
+  expect_equal(tab$classif.ce[1], NaN)
+})
