@@ -235,3 +235,26 @@ test_that("learners are cloned when hotstarting is applied", {
   expect_equal(bmr$resample_result(1)$learners[[1]]$model$id,
     hot$stack$start_learner[[1]]$model$id)
 })
+
+test_that("hotstarting works when col role is set in task", {
+  task = tsk("pima")
+  task$col_roles$stratum = task$target_names
+  learner_1 = lrn("classif.debug", iter = 1)
+  resampling = rsmp("holdout")
+  resampling$instantiate(task)
+
+  rr = resample(task, learner_1, resampling, store_models = TRUE)
+
+  learner = lrn("classif.debug", iter = 2)
+  hot = HotstartStack$new(rr$learners)
+  learner$hotstart_stack = hot
+
+  rr_2 = resample(task, learner, resampling, store_models = TRUE, allow_hotstart = TRUE)
+  pwalk(list(rr$learners, rr_2$learners), function(l1, l2) {
+    expect_equal(l2$param_set$values$iter, 2)
+    expect_class(l2$model, "classif.debug_model")
+    expect_equal(l2$model$iter, 2)
+    expect_equal(l1$model$id, l2$model$id)
+    expect_null(l2$hotstart_stack)
+  })
+})
